@@ -1,22 +1,21 @@
 /*
- * Copyright (c) 1998-2005 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -37,12 +36,26 @@ extern "C" vm_offset_t ml_io_map(vm_offset_t phys_addr, vm_size_t size);
 #define super IOService
 OSDefineMetaClassAndStructors( PPCI2CInterface, IOService )
 
+static IOService * pmu;
+
+static const OSSymbol *i2cCommandSym;
+static const OSSymbol *i2cOpenSym;
+static const OSSymbol *i2cCloseSym;
+
 // Uncomment the following define if you wish ro see more logging
 // on the i2c interface. Note: use this only in polling mode since
 // IOLog panics when used in primary interrupt context.
 // #define DEBUGMODE 
 // #define DEBUGPMU  // for just PMU i2c related debug logs
 
+// Add macros so that there aren't #ifdef DEBUGMODE / #endif combos around
+// any given IOLog()
+#ifdef DEBUGMODE
+#define DEBUGLOG(fmt, args...)  IOLog(fmt, ## args)
+#else
+#define DEBUGLOG(fmt, args...)
+#endif
+
 // Delay after accessing to an I2C register
 #define I2C_REGISTERDELAY 10
 
@@ -51,17 +64,13 @@ OSDefineMetaClassAndStructors( PPCI2CInterface, IOService )
 
 // FIXME: change the if 0 into if 1 in the following line for final
 // builds so all the simple private functions can be inlined.
-#if 1
+#if TRUE
 #define INLINE inline
 #else
 #define INLINE
 #endif
 
 #if defined( __ppc__ )
-
-// number of SpinLoops per 1000 microseconds
-static UInt32 gLoopsPerMic;
-
 static UInt64 SpinLoop (UInt32 spinCount) {
 	AbsoluteTime start, end;
 	SInt64 startnano, delta;
@@ -95,16 +104,14 @@ static void SpinDelay (UInt32 delay, UInt32 loopsPerMic) {
 INLINE void
 PPCI2CInterface::dumpI2CRegisters()
 {
-#ifdef DEBUGMODE
-    IOLog("mode    0x%08lx -> 0x%02x\n", (UInt32)mode,*mode);
-    IOLog("control 0x%08lx -> 0x%02x\n", (UInt32)control,*control);
-    IOLog("status  0x%08lx -> 0x%02x\n", (UInt32)status,*status);
-    IOLog("ISR     0x%08lx -> 0x%02x\n", (UInt32)ISR,*ISR);
-    IOLog("IER     0x%08lx -> 0x%02x\n", (UInt32)IER,*IER);
-    IOLog("address 0x%08lx -> 0x%02x\n", (UInt32)address,*address);
-    IOLog("subAddr 0x%08lx -> 0x%02x\n", (UInt32)subAddr,*subAddr);
-    //IOLog("data    0x%08lx -> 0x%02x\n", (UInt32)data,*data);
-#endif //DEBUGMODE
+    DEBUGLOG("mode    0x%08lx -> 0x%02x\n", (UInt32)mode,*mode);
+    DEBUGLOG("control 0x%08lx -> 0x%02x\n", (UInt32)control,*control);
+    DEBUGLOG("status  0x%08lx -> 0x%02x\n", (UInt32)status,*status);
+    DEBUGLOG("ISR     0x%08lx -> 0x%02x\n", (UInt32)ISR,*ISR);
+    DEBUGLOG("IER     0x%08lx -> 0x%02x\n", (UInt32)IER,*IER);
+    DEBUGLOG("address 0x%08lx -> 0x%02x\n", (UInt32)address,*address);
+    DEBUGLOG("subAddr 0x%08lx -> 0x%02x\n", (UInt32)subAddr,*subAddr);
+    //DEBUGLOG("data    0x%08lx -> 0x%02x\n", (UInt32)data,*data);
 }
 
 // --------------------------------------------------------------------------
@@ -137,7 +144,7 @@ PPCI2CInterface::SetI2CBase(UInt8 *baseAddress, UInt8 steps)
         getMode();
 
 #ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::SetI2CBase(0x%08lx,0x%02x)\n",(UInt32)baseAddress, steps);
+        DEBUGLOG("PPCI2CInterface::SetI2CBase(0x%08lx,0x%02x)\n",(UInt32)baseAddress, steps);
         dumpI2CRegisters();
 #endif // DEBUGMODE
     }
@@ -183,13 +190,11 @@ PPCI2CInterface::writeRegisterField(I2CRegister reg, UInt8 mask, UInt8 shift, UI
     eieio();
     I2CIODelay(I2C_REGISTERDELAY);
     
-#ifdef DEBUGMODE
-    IOLog("PPCI2CInterface::writeRegisterField(0x%08lx, 0x%02x, 0x%02x, 0x%02x)\n",(UInt32)reg, mask, shift, newData);
-    IOLog("PPCI2CInterface::writeRegisterField() registerValue=0x%02x\n", registerValue);
-    IOLog("PPCI2CInterface::writeRegisterField() data=0x%02x\n", data);
-    IOLog("PPCI2CInterface::writeRegisterField() nMask=0x%02x\n", nMask);
-    IOLog("PPCI2CInterface::writeRegisterField() *reg=0x%02x\n", *reg);
-#endif // DEBUGMODE
+    DEBUGLOG("PPCI2CInterface::writeRegisterField(0x%08lx, 0x%02x, 0x%02x, 0x%02x)\n",(UInt32)reg, mask, shift, newData);
+    DEBUGLOG("PPCI2CInterface::writeRegisterField() registerValue=0x%02x\n", registerValue);
+    DEBUGLOG("PPCI2CInterface::writeRegisterField() data=0x%02x\n", data);
+    DEBUGLOG("PPCI2CInterface::writeRegisterField() nMask=0x%02x\n", nMask);
+    DEBUGLOG("PPCI2CInterface::writeRegisterField() *reg=0x%02x\n", *reg);
 }
 
 // --------------------------------------------------------------------------
@@ -205,11 +210,9 @@ PPCI2CInterface::readRegisterField(I2CRegister reg, UInt8 mask, UInt8 shift)
     UInt8 registerValue = *reg;
     UInt8 returnValue = ((registerValue) >> shift) & mask;
 
-#ifdef DEBUGMODE
-    IOLog("PPCI2CInterface::readRegisterField(0x%08lx, 0x%02x, 0x%02x)\n",(UInt32)reg, mask, shift);
-    IOLog("PPCI2CInterface::readRegisterField() *reg=0x%02x\n", *reg);
-    IOLog("PPCI2CInterface::readRegisterField() returnValue=0x%02x\n", returnValue);
-#endif // DEBUGMODE
+    DEBUGLOG("PPCI2CInterface::readRegisterField(0x%08lx, 0x%02x, 0x%02x)\n",(UInt32)reg, mask, shift);
+    DEBUGLOG("PPCI2CInterface::readRegisterField() *reg=0x%02x\n", *reg);
+    DEBUGLOG("PPCI2CInterface::readRegisterField() returnValue=0x%02x\n", returnValue);
 
     return returnValue;
 }
@@ -359,19 +362,19 @@ PPCI2CInterface::setAddressRegister(UInt8 newAddress, I2CRWMode readMode)
 {
     newAddress &= kADDRMask;
     
-    if (pseudoI2C) {
+    if (pseudoI2C)
+	{
         currentAddress = (newAddress << I2CAddressShift) | readMode;
-        }
-    else {
+	}
+    else
+	{
         *address = (newAddress << I2CAddressShift) | readMode;
         I2CIODelay(I2C_REGISTERDELAY);
 
-#ifdef DEBUGMODE
-    IOLog("setAddressRegister( 0x%02x, %d) = 0x%02x\n", newAddress, (UInt8)readMode, (UInt8)*address);
-#endif // DEBUGMODE
+		DEBUGLOG("setAddressRegister( 0x%02x, %d) = 0x%02x\n", newAddress, (UInt8)readMode, (UInt8)*address);
 
         eieio();
-        }
+	}
 }
 
 INLINE UInt8
@@ -453,9 +456,7 @@ PPCI2CInterface::setAddressAndDirection()
     currentState = ki2cStateWaitingForIADDR;
     setControl((I2CControl)(getControl() | kXAddrCNTRL));
 
-#ifdef DEBUGMODE
-    IOLog("PPCI2CInterface::setAddressAndDirection()\n");
-#endif // DEBUGMODE
+    DEBUGLOG("PPCI2CInterface::setAddressAndDirection()\n");
 
     return(true);
 }
@@ -470,17 +471,15 @@ PPCI2CInterface::i2cStandardSubModeInterrupts(UInt8 interruptStatus)
 {
     bool success = true;
 
-    switch (currentState) {
+    switch (currentState)
+	{
         case ki2cStateWaitingForIADDR:
-#ifdef DEBUGMODE            
-            IOLog("ki2cStateWaitingForIADDR: ");
-#endif // DEBUGMODE            
+            DEBUGLOG("ki2cStateWaitingForIADDR: ");
 
             // verify that correct interrupt bit set
-            if ((interruptStatus & kIAddrISR) == 0) {
-#ifdef DEBUGMODE            
-                IOLog("PPCI2CInterface::i2cStandardSubModeInterrupts (ki2cStateWaitingForIADDR): bad state ");
-#endif
+            if ((interruptStatus & kIAddrISR) == 0)
+			{
+                DEBUGLOG("PPCI2CInterface::i2cStandardSubModeInterrupts (ki2cStateWaitingForIADDR): bad state ");
                 success = false;
             }
 
@@ -503,9 +502,9 @@ PPCI2CInterface::i2cStandardSubModeInterrupts(UInt8 interruptStatus)
                     else {
                         // no slave responded, so wait for STOP (control bit does not need to be set,
                         // since NAAK sets the control bit automatically)
-#ifdef DEBUGMODE            
-                        IOLog("ki2cStateWaitingForIADDR...no slave...");
-#endif
+
+                        DEBUGLOG("ki2cStateWaitingForIADDR...no slave...");
+
                         currentState = ki2cStateWaitingForISTOP;
                         success = false;
                     }
@@ -520,14 +519,15 @@ PPCI2CInterface::i2cStandardSubModeInterrupts(UInt8 interruptStatus)
             break;
 
         case ki2cStateWaitingForIDATA:
-#ifdef DEBUGMODE            
-            IOLog("ki2cStateWaitingForIDATA: ");
-#endif
+
+            DEBUGLOG("ki2cStateWaitingForIDATA: ");
+
             // verify that correct interrupt bit set
-            if ((interruptStatus & kIDataISR) == 0) {
-#ifdef DEBUGMODE            
-                IOLog("PPCI2CInterface::i2cStandardSubModeInterrupts (ki2cStateWaitingForIDATA): bad state ");
-#endif
+            if ((interruptStatus & kIDataISR) == 0)
+			{
+
+                DEBUGLOG("PPCI2CInterface::i2cStandardSubModeInterrupts (ki2cStateWaitingForIDATA): bad state ");
+
                 success = false;
             }
 
@@ -558,12 +558,13 @@ PPCI2CInterface::i2cStandardSubModeInterrupts(UInt8 interruptStatus)
                                 nBytes--;
                             }
                         }
-                       else {
+                       else
+					   {
                            // no slave responded, so wait for STOP (control bit does not need to be set,
                            // since NAAK sets the control bit automatically)
-#ifdef DEBUGMODE            
-                           IOLog("ki2cStateWaitingForIDATA...no slave...");
-#endif
+
+                           DEBUGLOG("ki2cStateWaitingForIDATA...no slave...");
+
                            currentState = ki2cStateWaitingForISTOP;
                            success = false;
                         }
@@ -579,14 +580,15 @@ PPCI2CInterface::i2cStandardSubModeInterrupts(UInt8 interruptStatus)
             break;
 
         case ki2cStateWaitingForISTOP:
-#ifdef DEBUGMODE
-            IOLog("ki2cStateWaitingForISTOP: ");
-#endif
+
+            DEBUGLOG("ki2cStateWaitingForISTOP: ");
+
             // verify that correct interrupt bit set
-            if ((interruptStatus & kIStopISR) == 0) {
-#ifdef DEBUGMODE
-                IOLog("PPCI2CInterface::i2cStandardSubModeInterrupts (ki2cStateWaitingForISTOP): bad state ");
-#endif
+            if ((interruptStatus & kIStopISR) == 0)
+			{
+
+                DEBUGLOG("PPCI2CInterface::i2cStandardSubModeInterrupts (ki2cStateWaitingForISTOP): bad state ");
+
                 success = false;
             }
 
@@ -596,23 +598,23 @@ PPCI2CInterface::i2cStandardSubModeInterrupts(UInt8 interruptStatus)
            break;
 
         case ki2cStateWaitingForISTART:
-#ifdef DEBUGMODE
-            IOLog("ki2cStateWaitingForISTART: is not supposed to happen in this state machine ");
-#endif
+
+            DEBUGLOG("ki2cStateWaitingForISTART: is not supposed to happen in this state machine ");
+
             break;
 
         case ki2cStateIdle:
-#ifdef DEBUGMODE
-            IOLog("ki2cStateIdle: ");
-#endif
+
+            DEBUGLOG("ki2cStateIdle: ");
+
             break;
 
         default:
              break;
     }
-#ifdef DEBUGMODE
-    IOLog(" %s\n", (success ? "true" : "false"));
-#endif
+
+    DEBUGLOG(" %s\n", (success ? "true" : "false"));
+
 
     // tell the system that this interrupt has been serviced
     return success;
@@ -669,16 +671,18 @@ PPCI2CInterface::waitForCompletion()
             handleI2CInterrupt();
     }
     
-    if (currentState != ki2cStateIdle) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::waitForCompletion error loop is incomplete\n");
-#endif
+    if (currentState != ki2cStateIdle)
+	{
+
+        DEBUGLOG("PPCI2CInterface::waitForCompletion error loop is incomplete\n");
+
         return false;
     }
-    else {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::waitForCompletion loop is complete\n");
-#endif
+    else
+	{
+
+        DEBUGLOG("PPCI2CInterface::waitForCompletion loop is complete\n");
+
         return true;        
     }
 }
@@ -704,9 +708,9 @@ PPCI2CInterface::setKhzSpeed(UInt speed)
             break;
 
         default:
-#ifdef DEBUGMODE
-            IOLog("PPCI2CInterface::setKhzSpeed Can not set bus speed %d is not allowed\n", speed);
-#endif
+
+            DEBUGLOG("PPCI2CInterface::setKhzSpeed Can not set bus speed %d is not allowed\n", speed);
+
             return false;
             break;
     }
@@ -747,9 +751,9 @@ PPCI2CInterface::handleI2CInterrupt()
     switch(lastMode)
     {
         case kDumbMode:
-#ifdef DEBUGMODE
-            IOLog("PPCI2CInterface::handleI2CInterrupt kDumbMode is an unsupported mode (for now)\n");
-#endif
+
+            DEBUGLOG("PPCI2CInterface::handleI2CInterrupt kDumbMode is an unsupported mode (for now)\n");
+
             break;
 
         case kStandardMode:
@@ -765,11 +769,11 @@ PPCI2CInterface::handleI2CInterrupt()
     // Update the transfer status:
     transferWasSuccesful = (transferWasSuccesful && success);
 
-#ifdef DEBUGMODE
-    IOLog("PPCI2CInterface::handleI2CInterrupt transferWasSuccesful = %s success= %s.\n",
+
+    DEBUGLOG("PPCI2CInterface::handleI2CInterrupt transferWasSuccesful = %s success= %s.\n",
               ((transferWasSuccesful) ? "true" : "false"),
               (success ? "true" : "false"));
-#endif // DEBUGMODE
+
 
     // By default we fail ...
     return success;
@@ -781,7 +785,7 @@ PPCI2CInterface::handleI2CInterrupt()
 bool
 PPCI2CInterface::start(IOService *provider)
 {
-    OSData *t;
+    OSData *aPropertyPtr;
     UInt32 baseAddress;
     UInt32 addressSteps;
     UInt32 rate;
@@ -794,97 +798,103 @@ PPCI2CInterface::start(IOService *provider)
     i2cRegisterMap = NULL;
 
     if (!super::start(provider)) return false;	//this was just added..
+	
+	i2cCommandSym = OSSymbol::withCString( "sendSMUI2CCommand" );
+	i2cOpenSym    = OSSymbol::withCString( "openSMUI2CCommand" );
+	i2cCloseSym   = OSSymbol::withCString( "closeSMUI2CCommand" );
     
     //see if we are attached to pmu-i2c or smu-i2c node, and if so set pseudoI2C = TRUE.
     retrieveProperty(provider);
 
     // Creates the mutex lock to provide atomic access to the services of the I2C bus:
     mutexLock = IORecursiveLockAlloc();
-    if (mutexLock == NULL) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::start  can not create the IORecursiveLock so we bail off\n");
-#endif
+    if (mutexLock == NULL)
+	{
+
+        DEBUGLOG("PPCI2CInterface::start  can not create the IORecursiveLock so we bail off\n");
+
         return false;
     }
     IORecursiveLockLock(mutexLock);  //Keep clients from accessing until start is complete
 
-#ifdef DEBUGMODE
-    IOLog("PPCI2CInterface::start(%s)\n", provider->getName());
-#endif
+    DEBUGLOG("PPCI2CInterface::start(%s)\n", provider->getName());
     
     // sets up the interface:
-#if 1
-
+#if TRUE
     //if PMU-I2C, skip the following... 
-    if (!pseudoI2C) {
+    if ( ! pseudoI2C )
+	{
+		aPropertyPtr = OSDynamicCast(OSData, provider->getProperty("AAPL,address"));
+		if (aPropertyPtr != NULL)
+		{
+			baseAddress = *((UInt32*)aPropertyPtr->getBytesNoCopy());
+			baseAddress = ml_io_map(baseAddress, 0x1000);
+			//baseAddress = (UInt32)pmap_extract(kernel_pmap,(vm_address_t)baseAddress);
+		}
+		else
+		{
 
-    t = OSDynamicCast(OSData, provider->getProperty("AAPL,address"));
-    if (t != NULL) {
-        baseAddress = *((UInt32*)t->getBytesNoCopy());
-        baseAddress = ml_io_map(baseAddress, 0x1000);
-        //baseAddress = (UInt32)pmap_extract(kernel_pmap,(vm_address_t)baseAddress);
-    }
-    else {
-#ifdef DEBUGMODE
-        IOLog( "PPCI2CInterface::start missing property AAPL,address in i2c registry\n");
-#endif
-        return false;
-    }
-#else
-    i2cRegisterMap = provider->mapDeviceMemoryWithIndex(1);
-    if ( i2cRegisterMap == NULL ) {
-#ifdef DEBUGMODE
-        IOLog( "PPCI2CInterface::start missing i2cRegisterMap\n");
-#endif
-        return false;
-    }
-    else
-        baseAddress = (UInt32)pmap_extract(kernel_pmap,(vm_address_t)i2cRegisterMap->getVirtualAddress());
-#endif
+			DEBUGLOG( "PPCI2CInterface::start missing property AAPL,address in i2c registry\n");
 
-    t = OSDynamicCast(OSData, provider->getProperty("AAPL,address-step"));
-    if (t != NULL)
-        addressSteps = *((UInt32*)t->getBytesNoCopy());
-    else {
-#ifdef DEBUGMODE
-        IOLog( "PPCI2CInterface::start missing property AAPL,address-step in i2c registry\n");
-#endif
-        return false;
-    }
+			return false;
+		}
 
-    t = OSDynamicCast(OSData, provider->getProperty("AAPL,i2c-rate"));
-    if (t != NULL)
-        rate = *((UInt32*)t->getBytesNoCopy());
-    else {
-#ifdef DEBUGMODE
-        IOLog( "PPCI2CInterface::start missing property AAPL,i2c-rate in i2c registry\n");
-#endif
-        return false;
-    }
+#else	// old code - no longer used
 
-    if (!initI2CBus((UInt8*)baseAddress, (UInt8)addressSteps))   
-    return false;
+		i2cRegisterMap = provider->mapDeviceMemoryWithIndex(1);
+		if ( i2cRegisterMap == NULL )
+		{
 
-    } // This bracket ends the !pseudoI2C case.
-        
-    if (pseudoI2C) {
+			DEBUGLOG( "PPCI2CInterface::start missing i2cRegisterMap\n");
+
+			return false;
+		}
+		else
+			baseAddress = (UInt32)pmap_extract(kernel_pmap,(vm_address_t)i2cRegisterMap->getVirtualAddress());
+#endif	// TRUE
+
+		aPropertyPtr = OSDynamicCast(OSData, provider->getProperty("AAPL,address-step"));
+		if (aPropertyPtr != NULL)
+			addressSteps = *((UInt32*)aPropertyPtr->getBytesNoCopy());
+		else
+		{
+			// one could argue that this should be a non-debug kprintf()...
+			DEBUGLOG( "PPCI2CInterface::start missing property AAPL,address-step in i2c registry\n");
+
+			return false;
+		}
+
+		aPropertyPtr = OSDynamicCast(OSData, provider->getProperty("AAPL,i2c-rate"));
+		if (aPropertyPtr == NULL)	// unable to find 'AAPL,ic2-rate' property - warn and exit
+		{
+			// one could argue that this should be a non-debug kprintf()...
+			DEBUGLOG( "PPCI2CInterface::start missing property AAPL,i2c-rate in i2c registry\n");
+
+			return false;
+		}
+		rate = *((UInt32*)aPropertyPtr->getBytesNoCopy());
+
+		if (!initI2CBus((UInt8*)baseAddress, (UInt8)addressSteps))   
+			return false;
+
+		if (!setKhzSpeed((UInt) rate))
+			return false;
+
+    } // if ( ! pseudoI2C )
+	else	// if ( pseudoI2C )
+	{
         setKhzSpeed(100);     	 // PMU case specifics
     	clientMutexLock = NULL;  // Creates the mutex lock to protect the PMU clients list
         clientMutexLock = IOLockAlloc();
-        }
-        
-    else if (!setKhzSpeed((UInt)rate))
-        return false;
+	}
 
 #if defined( __ppc__ )
-	if ( i2cUniN == TRUE ) {
-		loopTime = SpinLoop (100000) / 1000;				// loopTime time in microseconds
-		gLoopsPerMic = ((100000 / loopTime) * 4) / 3;		// number of loops per microsecond - 4/3 is fudge factor for vagaries of spin loops
-		if (gLoopsPerMic == 0)
-			gLoopsPerMic = 1;								// make sure we do at least one loop
-	}
+	loopTime = SpinLoop (100000) / 1000;				// loopTime time in microseconds
+	loopsPerMic = ((100000 / loopTime) * 4) / 3;		// number of loops per microsecond - 4/3 is fudge factor for vagaries of spin loops
+	if (loopsPerMic == 0)
+		loopsPerMic = 1;								// make sure we do at least one loop
 #endif
-
+	
     // remembers the provider:
     myProvider = provider;
 
@@ -1045,11 +1055,12 @@ PPCI2CInterface::setPollingMode(bool newPollingMode)
 #endif // DEBUGMODE
     // If I am not the owner of the lock returns without doing anything.
 	// Interrupt context calls do not (should not) call setPollingMode currently...
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::setPollingMode(%s) I am not the owner of the lock returns without doing anything.\n",
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+        DEBUGLOG("PPCI2CInterface::setPollingMode(%s) I am not the owner of the lock returns without doing anything.\n",
               (newPollingMode ? "true" : "false"));
-#endif // DEBUGMODE
+
         return false;   
     }
 
@@ -1102,10 +1113,11 @@ void
 PPCI2CInterface::setDumbMode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::setDumbMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+        DEBUGLOG("PPCI2CInterface::setDumbMode I am not the owner of the lock returns without doing anything.\n");
+
         return;
     }
 
@@ -1119,10 +1131,11 @@ void
 PPCI2CInterface::setStandardMode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::setStandardMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+        DEBUGLOG("PPCI2CInterface::setStandardMode I am not the owner of the lock returns without doing anything.\n");
+
         return;
     }
 
@@ -1136,10 +1149,11 @@ PPCI2CInterface::setStandardSubMode()
 {
 	if (!ml_at_interrupt_context())
 		// If I am not the owner of the lock returns without doing anything.
-		if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-       	 IOLog("PPCI2CInterface::setStandardSubMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+		if (!IORecursiveLockHaveLock(mutexLock))
+		{
+
+			DEBUGLOG("PPCI2CInterface::setStandardSubMode I am not the owner of the lock returns without doing anything.\n");
+
 			return;
 		}
 
@@ -1152,14 +1166,15 @@ PPCI2CInterface::setStandardSubMode()
 void
 PPCI2CInterface::setCombinedMode()
 {
- 	if (!ml_at_interrupt_context())
-	   // If I am not the owner of the lock returns without doing anything.
-	    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-	        IOLog("PPCI2CInterface::setCombinedMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
-	        return;
-	    }
+	if (!ml_at_interrupt_context())
+		// If I am not the owner of the lock returns without doing anything.
+		if (!IORecursiveLockHaveLock(mutexLock))
+		{
+
+			DEBUGLOG("PPCI2CInterface::setCombinedMode I am not the owner of the lock returns without doing anything.\n");
+
+			return;
+		}
 
     if (pseudoI2C)
         setMode(kCombinedI2CStream);
@@ -1172,10 +1187,11 @@ bool
 PPCI2CInterface::isInDumbMode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::isInDumbMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+        DEBUGLOG("PPCI2CInterface::isInDumbMode I am not the owner of the lock returns without doing anything.\n");
+
         return false;
     }
     
@@ -1186,10 +1202,11 @@ bool
 PPCI2CInterface::isInStandardMode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::isInStandardMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+        DEBUGLOG("PPCI2CInterface::isInStandardMode I am not the owner of the lock returns without doing anything.\n");
+
         return false;
     }
 
@@ -1201,10 +1218,11 @@ bool
 PPCI2CInterface::isInStandardSubMode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::isInStandardSubMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+    {
+
+        DEBUGLOG("PPCI2CInterface::isInStandardSubMode I am not the owner of the lock returns without doing anything.\n");
+
         return false;
     }
     
@@ -1215,10 +1233,11 @@ bool
 PPCI2CInterface::isInCombinedMode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::isInCombinedMode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+        DEBUGLOG("PPCI2CInterface::isInCombinedMode I am not the owner of the lock returns without doing anything.\n");
+
         return false;
     }
 
@@ -1230,10 +1249,11 @@ UInt
 PPCI2CInterface::getKhzSpeed()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-            IOLog("PPCI2CInterface::getKhzSpeed I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+
+            DEBUGLOG("PPCI2CInterface::getKhzSpeed I am not the owner of the lock returns without doing anything.\n");
+
         return 0;
     }
     switch((int)getSpeed())
@@ -1264,30 +1284,30 @@ PPCI2CInterface::openI2CBus(UInt8 port)
     // touch the i2C bus (until we close it).
 
 #ifdef DEBUGMODE
-    //if (!IORecursiveLockTryLock(mutexLock)) {
+    //if (!IORecursiveLockTryLock(mutexLock))
+	//{
     //    IOLog("PPCI2CInterface::openI2CBus PPCI2CInterface->mutexLock is already locked and I can't take it.\n");
     //    return false;
     //}
-
-    IOLog("PPCI2CInterface::openI2CBus attempting to access to PPCI2CInterface->mutexLock.\n");
-    IORecursiveLockLock(mutexLock);
-    IOLog("PPCI2CInterface::openI2CBus PPCI2CInterface->mutexLock locked.\n");
-#else // !DEBUGMODE
-    IORecursiveLockLock(mutexLock);
 #endif // DEBUGMODE
 
+    DEBUGLOG("PPCI2CInterface::openI2CBus attempting to access to PPCI2CInterface->mutexLock.\n");
+    IORecursiveLockLock(mutexLock);
+    DEBUGLOG("PPCI2CInterface::openI2CBus PPCI2CInterface->mutexLock locked.\n");
+
 	if (i2cSMU)  //ask SMU to take a lock
 		{
 		if (kIOReturnSuccess != AppleSMUSendI2CCommand( myProvider, (IOByteCount)portRegSelect, NULL, NULL, NULL, kSMU_Open ))
 			kprintf("PPCI2CInterface::openI2CBus ON SMU DIDN'T WORK !!\n");
 		}
 		
-    if (pseudoI2C)  {
+    if (pseudoI2C)
+	{
         lastMode = kSimpleI2CStream;	//Default case, unless changed after openI2CBus with set...Mode command
 #ifdef DEBUGPMU
         IOLog(" APPLE I2C-PMU  Try to open I2CBus..................port = 0x%2x, mode = 0x%2x\n", port, lastMode);
 #endif // DEBUGPMU
-        }
+	}
 	
 	// In i2cSMU case, setPort() uses portRegSelect from "reg" property instead of port.
     setPort(port);
@@ -1315,10 +1335,10 @@ PPCI2CInterface::writeI2CBus(UInt8 address, UInt8 subAddress, UInt8 *newData, UI
 	// you better know what you're doing
 	if (!ml_at_interrupt_context())
 		// If I am not the owner of the lock returns without doing anything.
-		if (!IORecursiveLockHaveLock(mutexLock)) {
-	#if DEBUGMODE
-			IOLog("PPCI2CInterface::writeI2CBus I am not the owner of the lock returns without doing anything.\n");
-	#endif // DEBUGMODE
+		if (!IORecursiveLockHaveLock(mutexLock))
+		{
+			DEBUGLOG("PPCI2CInterface::writeI2CBus I am not the owner of the lock returns without doing anything.\n");
+
 			return false;
 		}
 
@@ -1411,10 +1431,9 @@ PPCI2CInterface::readI2CBus(UInt8 address, UInt8 subAddress, UInt8 *newData, UIn
 	// you better know what you're doing
 	if (!ml_at_interrupt_context())
 		// If I am not the owner of the lock returns without doing anything.
-		if (!IORecursiveLockHaveLock(mutexLock)) {
-	#if DEBUGMODE
-			IOLog("PPCI2CInterface::readI2CBus I am not the owner of the lock returns without doing anything.\n");
-	#endif // DEBUGMODE
+		if (!IORecursiveLockHaveLock(mutexLock))
+		{
+			DEBUGLOG("PPCI2CInterface::readI2CBus I am not the owner of the lock returns without doing anything.\n");
 			return false;
 		}
 
@@ -1510,10 +1529,9 @@ PPCI2CInterface::closeI2CBus()
 {
 	// Interrupt context calls do not (should not) call openI2CBus ...
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#if DEBUGMODE
-            IOLog("PPCI2CInterface::closeI2CBus I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+            DEBUGLOG("PPCI2CInterface::closeI2CBus I am not the owner of the lock returns without doing anything.\n");
         return false;
     }
 
@@ -1531,9 +1549,8 @@ PPCI2CInterface::closeI2CBus()
     // And releases the lock:
     IORecursiveLockUnlock(mutexLock);
 
-#if DEBUGMODE
-    IOLog("PPCI2CInterface::closeI2CBus PPCI2CInterface->mutexLock unlocked.\n");
-#endif // DEBUGMODE
+    DEBUGLOG("PPCI2CInterface::closeI2CBus PPCI2CInterface->mutexLock unlocked.\n");
+
 #ifdef DEBUGPMU
     if (pseudoI2C)
         IOLog("      APPLE I2C-PMU  CLOSED ,  SUCCESSFULLY! \n");
@@ -1580,9 +1597,7 @@ PPCI2CInterface::getResourceName()
 			}
 		}
     
-#ifdef DEBUGMODE
-    IOLog("PPCI2CInterface::getResourceName returns \"%s\"\n",resourceName);
-#endif // DEBUGMODE
+    DEBUGLOG("PPCI2CInterface::getResourceName returns \"%s\"\n",resourceName);
     
     return (resourceName);
 }
@@ -1724,15 +1739,15 @@ PPCI2CInterface::ApplePMUSendMiscCommand( UInt32 command,
                         IOByteCount sendLength, UInt8 * sendBuffer,
                         IOByteCount * readLength, UInt8 * readBuffer )
 {
-    struct SendMiscCommandParameterBlock {
-        int command;  
-        IOByteCount sLength;
-        UInt8 *sBuffer;
-        IOByteCount *rLength; 
-        UInt8 *rBuffer;
-    };
-    IOReturn ret = kIOReturnError;
-    static IOService * pmu = 0;
+struct SendMiscCommandParameterBlock
+{
+	int command;  
+	IOByteCount sLength;
+	UInt8 *sBuffer;
+	IOByteCount *rLength; 
+	UInt8 *rBuffer;
+};
+IOReturn ret = kIOReturnError;
 
     // Wait for the PMU to show up:
     if( !pmu)
@@ -1918,10 +1933,10 @@ void
 PPCI2CInterface::setStandardSub4Mode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::setStandardSub4Mode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+        DEBUGLOG("PPCI2CInterface::setStandardSub4Mode I am not the owner of the lock returns without doing anything.\n");
+
         return;
     }
 
@@ -1942,10 +1957,10 @@ void
 PPCI2CInterface::setCombined4Mode()
 {
     // If I am not the owner of the lock returns without doing anything.
-    if (!IORecursiveLockHaveLock(mutexLock)) {
-#ifdef DEBUGMODE
-        IOLog("PPCI2CInterface::setCombined4Mode I am not the owner of the lock returns without doing anything.\n");
-#endif // DEBUGMODE
+    if (!IORecursiveLockHaveLock(mutexLock))
+	{
+        DEBUGLOG("PPCI2CInterface::setCombined4Mode I am not the owner of the lock returns without doing anything.\n");
+
         return;
     }
 
@@ -1969,9 +1984,6 @@ PPCI2CInterface::AppleSMUSendI2CCommand( IOService *smu,
         UInt8 *rBuffer;
     };
     IOReturn ret = kIOReturnError;
-	static const OSSymbol *i2cCommandSym = OSSymbol::withCStringNoCopy("sendSMUI2CCommand");
-	static const OSSymbol *i2cOpenSym = OSSymbol::withCStringNoCopy("openSMUI2CCommand");
-	static const OSSymbol *i2cCloseSym = OSSymbol::withCStringNoCopy("closeSMUI2CCommand");
 
     SendI2CCommandParameterBlock params = { sendLength, sendBuffer,
                                                       readLength, readBuffer };
@@ -2460,7 +2472,6 @@ PPCI2CInterface::calli2cClient(UInt8 interruptMask, UInt32 length, UInt8 * buffe
 PPCI2CInterface::registerForI2cInterrupts(UInt32 addressInfo, AppleI2Cclient function, IOService * caller)
 {
     IOReturn ret = kIOReturnError;
-    static IOService * pmu;
 
     // Wait for the PMU to show up.
     // If already register with PMU, don't bother registering again
